@@ -1,24 +1,21 @@
 package ExtUtils::ModuleMaker;
 use strict;
+local $^W = 1;
+use vars qw ($VERSION);
+$VERSION = 0.33;
 
 use ExtUtils::ModuleMaker::Licenses::Standard;
 use ExtUtils::ModuleMaker::Licenses::Local;
 use File::Path;
-use Data::Dumper;
 
-BEGIN {
-    use Exporter ();
-    use vars qw ($VERSION @ISA @EXPORT);
-    @ISA     = qw (Exporter);
-    $VERSION = 0.32_07; # hacked by James E Keenan January 3 2005
-
-}
+#################### PUBLICLY CALLABLE METHODS ####################
 
 #!#!#!#!#
 ##   2 ##
 sub new {
-    my ( $class, $paramsref ) = @_;
-    my %parameters = %{$paramsref};
+#    my ( $class, $paramsref ) = @_;
+#    my %parameters = %{$paramsref};
+    my ( $class, %parameters ) = @_;
     my $self = bless( default_values(), ref($class) || $class );
     foreach my $param ( keys %parameters ) {
         if ( ref( $parameters{$param} ) eq 'HASH' ) {
@@ -39,8 +36,64 @@ sub new {
     return ($self);
 }
 
+#!#!#!#!#
+##   7 ##
+sub complete_build {
+    my $self = shift;
+
+    $self->verify_values();
+
+    $self->create_base_directory();
+    $self->check_dir( map { "$self->{Base_Dir}/$_" } qw (lib t scripts) );
+
+    $self->print_file( 'LICENSE', $self->{LicenseParts}{LICENSETEXT} );
+    $self->print_file( 'README',  $self->file_text_README() );
+    $self->print_file( 'Todo',    $self->file_text_ToDo() );
+
+    unless ( $self->{CHANGES_IN_POD} ) {
+        $self->print_file( 'Changes', $self->file_text_Changes() );
+    }
+
+    my $ct = 1;
+    foreach my $module ( $self, @{ $self->{EXTRA_MODULES} } ) {
+        $self->generate_pm_file($module);
+        my $testfile = sprintf( "t/%03d_load.t", $ct );
+        $self->print_file( $testfile,
+            $self->file_text_test( $testfile, $module ) );
+        $ct++;
+    }
+
+    #Makefile must be created after generate_pm_file which sets $self->{FILE}
+    if ( $self->{BUILD_SYSTEM} eq 'ExtUtils::MakeMaker' ) {
+        $self->print_file( 'Makefile.PL', $self->file_text_Makefile() );
+    }
+    else {
+        $self->print_file( 'Build.PL', $self->file_text_Buildfile() );
+#        if ( $self->{BUILD_SYSTEM} eq 'Module::Build and proxy Makefile.PL' ) {
+	if ( $self->{BUILD_SYSTEM} eq 'Module::Build and proxy Makefile.PL' 
+         or  $self->{BUILD_SYSTEM} eq 'Module::Build and Proxy') {
+            $self->print_file( 'Makefile.PL',
+                $self->file_text_proxy_makefile() );
+        }
+    }
+
+    $self->print_file( 'MANIFEST', join( "\n", @{ $self->{MANIFEST} } ) );
+    return 1;
+}
+
+#################### INTERNAL SUBROUTINES ####################
+
 #!#!#!#!#
 ##   4 ##
+# Usage     : $self->default_values() inside new()
+# Purpose   : Defaults for new()
+# Returns   : A reference to a hash of defaults as the basis for 'new'.
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : Geoff probably put this into a subroutine so it would be 
+#             subclassable.  I'm leaving it here so that the defaults
+#             are encapsulated within a subroutine rather than creating
+#             a file-scoped lexical. 
 sub default_values {
     my %defaults = (
         NAME     => 'None yet',
@@ -77,6 +130,12 @@ ENDOFUSAGE
 
 #!#!#!#!#
 ##   6 ##
+# Usage     : $self->verify_values() within complete_build()
+# Purpose   : Verify module values are valid and complete.
+# Returns   : Error message if there is a problem
+# Argument  : n/a
+# Throws    : Will die with a death_message if errors and not interactive.
+# Comments  : 
 sub verify_values {
     my ($self) = @_;
     my @errors;
@@ -100,60 +159,18 @@ sub verify_values {
     $self->death_message(@errors);
 }
 
-#!#!#!#!#
-##   7 ##
-sub complete_build {
-    my $self = shift;
-
-    $self->verify_values();
-
-    $self->Create_Base_Directory();
-    $self->Check_Dir( map { "$self->{Base_Dir}/$_" } qw (lib t scripts) );
-
-    $self->print_file( 'LICENSE', $self->{LicenseParts}{LICENSETEXT} );
-    $self->print_file( 'README',  $self->FileText_README() );
-    $self->print_file( 'Todo',    $self->FileText_ToDo() );
-
-    unless ( $self->{CHANGES_IN_POD} ) {
-        $self->print_file( 'Changes', $self->FileText_Changes() );
-    }
-
-    my $ct = 1;
-    foreach my $module ( $self, @{ $self->{EXTRA_MODULES} } ) {
-        $self->generate_pm_file($module);
-        my $testfile = sprintf( "t/%03d_load.t", $ct );
-        $self->print_file( $testfile,
-            $self->FileText_Test( $testfile, $module ) );
-        $ct++;
-    }
-
-    #Makefile must be created after generate_pm_file which sets $self->{FILE}
-    if ( $self->{BUILD_SYSTEM} eq 'ExtUtils::MakeMaker' ) {
-        $self->print_file( 'Makefile.PL', $self->FileText_Makefile() );
-    }
-    else {
-        $self->print_file( 'Build.PL', $self->FileText_Buildfile() );
-        if ( $self->{BUILD_SYSTEM} eq 'Module::Build and proxy Makefile.PL' ) {
-            $self->print_file( 'Makefile.PL',
-                $self->FileText_Proxy_Makefile() );
-        }
-    }
-
-    $self->print_file( 'MANIFEST', join( "\n", @{ $self->{MANIFEST} } ) );
-}
-
 #!#!#!#!#
 ##   8 ##
 sub generate_pm_file {
     my ( $self, $module ) = @_;
 
-    $self->Create_PM_Basics($module);
+    $self->create_pm_basics($module);
 
-    my $page = $self->Block_Begin($module) .
+    my $page = $self->block_begin($module) .
 
       (
         ( $self->module_value( $module, 'NEED_POD' ) )
-        ? $self->Block_Module_Header($module)
+        ? $self->block_module_header($module)
         : ()
       )
       .
@@ -163,19 +180,19 @@ sub generate_pm_file {
                  ( $self->module_value( $module, 'NEED_POD' ) )
               && ( $self->module_value( $module, 'NEED_NEW_METHOD' ) )
         )
-        ? $self->Block_Subroutine_Header($module)
+        ? $self->block_subroutine_header($module)
         : ()
       )
       .
 
       (
         ( $self->module_value( $module, 'NEED_NEW_METHOD' ) )
-        ? $self->Block_New_Method($module)
+        ? $self->block_new_method($module)
         : ()
       )
       .
 
-      $self->Block_Final_One($module);
+      $self->block_final_one($module);
 
     $self->print_file( $module->{FILE}, $page );
 }
@@ -207,23 +224,29 @@ sub set_author_data {
 
 #!#!#!#!#
 ##  13 ##
-sub Create_Base_Directory {
+# Usage     : 
+# Purpose   : Create the directory where all the files will be created.
+# Returns    $DIR = directory name where the files will live
+# Argument   $package_name = name of module separated by '::'
+# Throws    : 
+# Comments  : see also:  check_dir()
+sub create_base_directory {
     my $self = shift;
 
     $self->{Base_Dir} =
       join( ( $self->{COMPACT} ) ? '-' : '/', split( /::|'/, $self->{NAME} ) );
-    $self->Check_Dir( $self->{Base_Dir} );
+    $self->check_dir( $self->{Base_Dir} );
 }
 
 #!#!#!#!#
 ##  14 ##
-sub Create_PM_Basics {
+sub create_pm_basics {
     my ( $self, $module ) = @_;
     my @layers = split( /::|'/, $module->{NAME} );
     my $file   = pop(@layers);
     my $dir    = join( '/', 'lib', @layers );
 
-    $self->Check_Dir("$self->{Base_Dir}/$dir");
+    $self->check_dir("$self->{Base_Dir}/$dir");
     $module->{FILE} = "$dir/$file.pm";
 }
 
@@ -277,6 +300,7 @@ sub print_file {
       unless ( $filename eq 'MANIFEST' );
     $self->log_message("writing file '$filename'");
 
+    local *FILE;
     open( FILE, ">$self->{Base_Dir}/$filename" )
       or $self->death_message("Could not write '$filename', $!");
     print FILE ($page);
@@ -285,7 +309,14 @@ sub print_file {
 
 #!#!#!#!#
 ##  19 ##
-sub Check_Dir {
+# Usage     : check_dir ($dir, $MODE);
+# Purpose   : Creates a directory with the correct mode if needed.
+# Returns   : n/a
+# Argument  : $dir = directory name
+#             $MODE = mode of directory (e.g. 0777, 0755)
+# Throws    : 
+# Comments  : 
+sub check_dir {
     my $self = shift;
 
     return mkpath( \@_, $self->{VERBOSE}, $self->{PERMISSIONS} );
@@ -351,7 +382,14 @@ EOFBLOCK
 
 #!#!#!#!#
 ##  25 ##
-sub Block_Begin {
+# Usage     : $self->block_begin() within generate_pm_file()
+# Purpose   : Build part of a module pm file
+# Returns   : Part of the file being built
+# Argument  : $module: pointer to the module being built, for the primary
+#                      module it is a pointer to $self
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub block_begin {
     my ( $self, $module ) = @_;
 
     my $version = $self->module_value( $module, 'VERSION' );
@@ -378,7 +416,14 @@ EOFBLOCK
 
 # #!#!#!#!#
 ##  29 ##
-sub Block_New_Method {
+# Usage     : $self->block_new_method() within generate_pm_file()
+# Purpose   : Build part of a module pm file
+# Returns   : Part of the file being built
+# Argument  : $module: pointer to the module being built, for the primary
+#                      module it is a pointer to $self
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub block_new_method {
     my ( $self, $module ) = @_;
 
     my $string = <<'EOFBLOCK';
@@ -399,7 +444,14 @@ EOFBLOCK
 
 #!#!#!#!#
 ##  31 ##
-sub Block_Module_Header {
+# Usage     : $self->block_module_header ()
+# Purpose   : Build part of a module pm file
+# Returns   : Part of the file being built
+# Argument  : $module: pointer to the module being built, for the primary
+#                      module it is a pointer to $self
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub block_module_header {
     my ( $self, $module ) = @_;
 
     my $description = <<EOFBLOCK;
@@ -428,7 +480,7 @@ EOFBLOCK
         (
             ( $self->{CHANGES_IN_POD} )
             ? $self->pod_section(
-                HISTORY => $self->FileText_Changes('only pod')
+                HISTORY => $self->file_text_Changes('only pod')
               )
             : ()
         ),
@@ -447,7 +499,14 @@ EOFBLOCK
 
 #!#!#!#!#
 ##  33 ##
-sub Block_Subroutine_Header {
+# Usage     : $self->block_subroutine_header() within generate_pm_file()
+# Purpose   : Build part of a module pm file
+# Returns   : Part of the file being built
+# Argument  : $module: pointer to the module being built, for the primary
+#                      module it is a pointer to $self
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub block_subroutine_header {
     my ( $self, $module ) = @_;
 
     my $string = <<EOFBLOCK;
@@ -478,7 +537,14 @@ EOFBLOCK
 
 #!#!#!#!#
 ##  35 ##
-sub Block_Final_One {
+# Usage     : $self->block_final_one ()
+# Purpose   : Make module return a true value
+# Returns   : Part of the file being built
+# Argument  : $module: pointer to the module being built, for the primary
+#                      module it is a pointer to $self
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub block_final_one {
     my ( $self, $module ) = @_;
 
     my $string = <<EOFBLOCK;
@@ -493,7 +559,13 @@ EOFBLOCK
 
 #!#!#!#!#
 ##  37 ##
-sub FileText_README {
+# Usage     : $self->file_text_README within complete_build()
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub file_text_README {
     my ($self) = @_;
 
     my $build_instructions;
@@ -538,7 +610,14 @@ EOF
 
 #!#!#!#!#
 ##  39 ##
-sub FileText_Changes {
+# Usage     : $self->file_text_Changes within block_module_header()
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : $only_in_pod:  True value to get only a HISTORY section for POD
+#                            False value to get whole Changes file
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub file_text_Changes {
     my ( $self, $only_in_pod ) = @_;
 
     my $page;
@@ -565,7 +644,13 @@ EOF
 
 #!#!#!#!#
 ##  41 ##
-sub FileText_ToDo {
+# Usage     : $self->file_text_ToDo() within complete_build()
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub file_text_ToDo {
     my ($self) = @_;
 
     my $page = <<EOF;
@@ -581,7 +666,13 @@ EOF
 
 #!#!#!#!#
 ##  43 ##
-sub FileText_Makefile {
+# Usage     : $self->file_text_Makefile 
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub file_text_Makefile {
     my ($self) = @_;
     my $page = <<EOF;
 use ExtUtils::MakeMaker;
@@ -602,7 +693,13 @@ EOF
 
 #!#!#!#!#
 ##  45 ##
-sub FileText_Buildfile {
+# Usage     : $self->file_text_Buildfile within complete_build() 
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub file_text_Buildfile {
     my ($self) = @_;
 
     # As of 0.15, Module::Build only allows a few licenses
@@ -634,7 +731,13 @@ EOF
 
 #!#!#!#!#
 ##  47 ##
-sub FileText_Proxy_Makefile {
+# Usage     : $self->file_text_proxy_makefile within complete_build()
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+sub file_text_proxy_makefile {
     my ($self) = @_;
 
     # This comes directly from the docs for Module::Build::Compat
@@ -673,7 +776,14 @@ EOF
 
 #!#!#!#!#
 ##  49 ##
-sub FileText_Test {
+# Usage     : $self->file_text_test within complete_build()
+# Purpose   : Build a supporting file
+# Returns   : Text of the file being built
+# Argument  : n/a
+# Throws    : n/a
+# Comments  : This method is a likely candidate for alteration in a subclass
+#             Will make a test with or without a checking for method new.
+sub file_text_test {
     my ( $self, $testnum, $module ) = @_;
 
     my $name    = $self->module_value( $module, 'NAME' );
@@ -722,7 +832,7 @@ EOF
 __END__
 
 #################### DOCUMENTATION ####################
-#
+
 #!#!#!#!#
 ##   1 ##
 
@@ -734,97 +844,85 @@ ExtUtils::ModuleMaker - Better than h2xs for creating modules
 
     use ExtUtils::ModuleMaker;
 
-    my $MOD = ExtUtils::ModuleMaker->new( {
+    $mod = ExtUtils::ModuleMaker->new(
         NAME => 'Sample::Module' 
-    } );
-    $MOD->complete_build ();
+    );
+    $mod->complete_build();
 
 =head1 DESCRIPTION
 
-This module is a replacement for the most typical use of the I<h2xs> 
+This module is a replacement for the most typical use of the F<h2xs> 
 utility bundled with all Perl distributions:  the creation of the 
 directories and files required for a pure-Perl module to be distributable 
 on the Comprehensive Perl Archive Network (CPAN).
 
-I<h2xs> has many options which are useful -- indeed, necessary -- for 
+F<h2xs> has many options which are useful -- indeed, necessary -- for 
 the creation of a properly structured distribution that includes C code 
-as well as Perl code, but most of the time it is used as follows:
+as well as Perl code.  Most of the time, however, F<h2xs> is used as follows
 
     % h2xs -AXn My::Module
 
 to create a distribution containing only Perl code.  ExtUtils::ModuleMaker is 
-intended to be an easy-to-use replacement for I<this> use of I<h2xs>.  
+intended to be an easy-to-use replacement for I<this> use of F<h2xs>.  
 
 While ExtUtils::ModuleMaker can be called from within a Perl script (as in 
 the SYNOPSIS above), it is most easily used by a command-prompt invocation 
-of the I<modulemaker> script bundled with this distribution:
+of the F<modulemaker> script bundled with this distribution:
 
     % modulemaker
 
 and then responding to the prompts.  For Perl programmers, laziness is a 
-virtue -- and I<modulemaker> is far and away the laziest way to create a 
+virtue -- and F<modulemaker> is the laziest way to create a 
 pure Perl distribution which meets all the requirements for worldwide 
 distribution via CPAN.
 
-=head1 INSTALLATION
-
-    perl Makefile.PL
-    make
-    make test
-    make install
-
-On Windows machines use I<nmake> rather than I<make>.
-
 =head1 USAGE
 
-=head2 Usage from the command-line with I<modulemaker>
+=head2 Usage from the command-line with F<modulemaker>
 
-The easiest, laziest way to use ExtUtils::Modulemaker is to invoke the 
-I<modulemaker> script from the command-line.  See the documentation for 
-I<modulemaker> bundled with this distribution.
+The easiest way to use ExtUtils::ModuleMaker is to invoke the 
+F<modulemaker> script from the command-line.  See the documentation for 
+F<modulemaker> bundled with this distribution.
 
 =head2 Usage within a Perl script
 
 In this version of ExtUtils::ModuleMaker there are only two publicly 
 callable functions.  These are how you should interact with this module.
 
-=over 4
+=head3 C<new>
 
-=item I<new>
-
-    Usage     : 
-    Purpose   : Creates an object for modules
-    Returns   : the module object
-    Argument  : A reference to a hash with the information for 
-                the new module(s)
-    Throws    : 
-    Comments  : 
+Creates and returns an ExtUtils::ModuleMaker object.  Takes a list 
+containing key-value pairs with information specifying the
+structure and content of the new module(s).  With the exception of 
+keys AUTHOR and EXTRA_MODULES (see below), the values in these pairs 
+are all strings.  Like most such lists of key-value pairs, this list 
+is probably best held in a hash.   Keys which may be specified are:
 
 =over 4
 
-=item NAME
+=item * NAME
 
 The I<only> required feature.  This is the name of the primary module 
 (with 'C<::>' separators if needed).  Will also support the older style 
-separator "C<'>" like the module I<D'Oh>.
+separator ''C<'>'' like the module F<D'Oh>.  Current default is 'None yet'. 
 
-=item ABSTRACT
+=item * ABSTRACT
 
 A short (44-character maximum) description of the module.  CPAN likes 
 to use this feature to describe the module.
 
-=item VERSION
+=item * VERSION
 
 A real number to be the version number.  Do not use Linux style numbering 
 with multiple dots like 2.4.24.  For alpha releases, include an underscore 
 to the right of the dot like 0.31_21. (Default is 0.01.)
 
-=item LICENSE
+=item * LICENSE
 
 Which license to include in the Copyright section.  You can choose one of 
 the standard licenses by including 'perl', 'gpl', 'artistic', and 18 others 
 approved by opensource.org.  The default is to choose the 'perl' flavor 
-which is to share it "under the same terms as Perl itself".
+which is to share it ''under the same terms as Perl itself.''
 
 Other licenses can be added by individual module authors to 
 ExtUtils::ModuleMaker::Licenses::Local to keep your company lawyers happy.
@@ -832,121 +930,139 @@ ExtUtils::ModuleMaker::Licenses::Local to keep your company lawyers happy.
 Some licenses include placeholders that will be replaced with AUTHOR 
 information.
 
-=item BUILD_SYSTEM
+=item * BUILD_SYSTEM
 
-This can take one of three values.  These are 'ExtUtils::MakeMaker',
-'Module::Build', and 'Module::Build and Proxy'.  The first generates a
-basic Makefile.PL file for your module.  The second creates a Build.PL
-file, and the last creates a Build.PL along with a proxy Makefile.PL
+This can take one of three values:  
+
+=over 4
+
+=item * C<'ExtUtils::MakeMaker'>
+
+The first generates a basic Makefile.PL file for your module.
+
+=item * C<'Module::Build'>
+
+The second creates a Build.PL file.
+
+=item * C<Module::Build and Proxy>
+
+The third creates a Build.PL along with a proxy Makefile.PL
 script that attempts to install Module::Build if necessary, and then
 runs the Build.PL script.  This option is recommended if you want to
 use Module::Build as your build system.  See Module::Build::Compat for
 more details.
 
-=item AUTHOR
+B<Note:>  To correct a discrepancy between the documentation and code in
+earlier versions of ExtUtils::ModuleMaker, we now explicitly provide
+this synonym for the third option:
+
+    'Module::Build and proxy Makefile.PL'
+
+(Thanks to David A Golden for spotting this bug.)
+
+=back
+
+=item * AUTHOR
 
 A hash containing information about the author to pass on to all the
 necessary places in the files.
 
 =over 4
 
-=item NAME
+=item * NAME
 
 Name of the author.
 
-=item EMAIL
+=item * EMAIL
 
 Email address of the author.
 
-=item CPANID
+=item * CPANID
 
 The CPANID of the author.  If this is omitted, then the line will not
 be added to the documentation.
 
-=item WEBSITE
+=item * WEBSITE
 
 The personal or organizational website of the author.
 
-=item ORGANIZATION
+=item * ORGANIZATION
 
 Company or group owning the module.  If this is omitted, then the line 
 will not be added to the documentation
 
 =back
 
-=item EXTRA_MODULES
+=item * EXTRA_MODULES
 
 An array of hashes that each contain values for additional modules in
 the distribution.  As with the primary module only NAME is required and
 primary module values will be used if no value is given here.
 
 Each extra module will be created in the correct relative place in the
-I<lib> directory, but no extra supporting documents, like README or
+F<lib> directory, but no extra supporting documents, like README or
 Changes.
 
-This is one major improvement over the earlier I<h2xs> as you can now
+This is one major improvement over the earlier F<h2xs> as you can now
 build multi-module packages.
 
-=item COMPACT
+=item * COMPACT
 
-For a module named "Foo::Bar::Baz" creates a base directory named
-"Foo-Bar-Baz" instead of Foo/Bar/Baz. (Default off)
+For a module named ''Foo::Bar::Baz'' creates a base directory named
+''Foo-Bar-Baz'' instead of Foo/Bar/Baz. (Default off)
 
-=item VERBOSE
+=item * VERBOSE
 
 Prints messages as it creates directories, writes files, etc. (Default off)
 
-=item INTERACTIVE
+=item * INTERACTIVE
 
 Suppresses 'die' when something goes wrong.  Should only be used by interactive
-scripts like I<modulemaker>. (Default off)
+scripts like F<modulemaker>. (Default off)
 
-=item PERMISSIONS
+=item * PERMISSIONS
 
 Used to create new directories.  (Default is 0755:  group and world can not 
 write.)
 
-=item USAGE_MESSAGE
+=item * USAGE_MESSAGE
 
 Message given when the module 'die's.  Scripts should set this to the same 
 string it would print if the user asked for help (often with a -h flag).
 
-=item NEED_POD
+=item * NEED_POD
 
 Include POD section in modules. (Default is on)
 
-=item NEED_NEW_METHOD
+=item * NEED_NEW_METHOD
 
 Include a simple 'new' method in the object oriented module.  (Default is on)
 
-=item CHANGES_IN_POD
+=item * CHANGES_IN_POD
 
 Don't include a 'Changes' file, but instead add a HISTORY section to the POD. 
 (Default is off).
 
 =back
 
-=item I<complete_build>
+=head3 C<complete_build>
 
-[to come]
-
-=back
-
-=cut
+Creates all directories and files as configured by the key-value pairs
+passed to C<ExtUtils::ModuleMaker::new>.  Returns a
+true value if all specified files are created -- but this says nothing
+about whether those files have been created with the correct content.
 
 =head1 SUPPORT
 
-Send email to modulemaker@PlatypiVentures.com.
+Send email to jkeenan [at] cpan [dot] org.  Please include 'modulemaker'
+in the subject line.
 
 =head1 AUTHOR
 
-    R. Geoffrey Avery
-    CPAN ID: RGEOFFREY
-    modulemaker@PlatypiVentures.com
-    http://www.PlatypiVentures.com/perl/modules/ModuleMaker.shtml
-
-Version 0.32_07 is an unofficial version containing revisions made by 
-James E. Keenan (jkeenan@cpan.org) on January 3 2005.
+ExtUtils::ModuleMaker was originally written in 2001-02 by R. Geoffrey Avery
+(modulemaker [at] PlatypiVentures [dot] com).  Since version 0.33 (July
+2005) it has been maintained by James E. Keenan (jkeenan [at] cpan [dot]
+org).
 
 =head1 COPYRIGHT
 
@@ -959,6 +1075,6 @@ LICENSE file included with this module.
 
 =head1 SEE ALSO
 
-I<modulemaker>, I<perlnewmod>, I<h2xs>, I<ExtUtils::MakeMaker>
+F<modulemaker>, F<perlnewmod>, F<h2xs>, F<ExtUtils::MakeMaker>.
 
 =cut
